@@ -5,9 +5,10 @@ use Mojo::Base -role;
 requires qw{ancestors at attr find matches selector tag val};
 
 sub target {
-  my ($self, $submit) = (shift, shift || '');
+  my ($self, $submit) = (shift, shift);
   return () if ($self->tag // '') ne 'form';
-  return () unless defined($submit = $self->at($submit));
+  return ()
+    unless defined($submit = $self->at($submit || _form_default_submit($self)));
   return () if $submit->matches('[disabled]');
   my $method = uc($submit->attr('formmethod') || $self->attr('method') || 'GET');
   my $action = $submit->attr('formaction') || $self->attr('action') || '#';
@@ -19,7 +20,7 @@ sub target {
 around val => sub {
   my ($orig, $self, @args) = @_;
   # "form"
-  return {
+  return
     $self->find('button, checkbox, input, radio, select, textarea')
       ->map(sub {
         my $is_image = !!$_->matches('input[type=image]');
@@ -32,11 +33,18 @@ around val => sub {
         # client only buttons ignored
         return () if _form_element_client_only_button($_);
         # simply return name => value for all but image types
-        return $name => $_->val() unless $is_image;
+        return [$name => $_->val()] unless $is_image;
         # synthesize image click
         return _form_image_click($_, $name);
-      }, $args[0] || _form_default_submit($self))->each,
-  } if (my $tag = $self->tag) eq 'form';
+      }, $args[0] || _form_default_submit($self))
+      ->reduce(sub {
+        my ($key, $value) = @$b;
+        $a->{$key} = defined $a->{$key} && defined($value)
+          ? [ ref($a->{$key}) ? (@{$a->{$key}}, $value) : ($a->{$key}, $value) ]
+          : $value;
+        $a
+      }, {})
+  if (my $tag = $self->tag) eq 'form';
 
   # "option"
   return $self->{value} // $self->text if $tag eq 'option';
@@ -70,10 +78,10 @@ sub _form_default_submit {
     # only the first continues, save some cycles
     ->tap(sub { splice @$_, 1; })
     ->map(sub {
-      $_->selector;
-      # get the selector and relativise to form - not req
-      # (my $s = $_->selector) =~ s/^.*form[^\s]*\s>\s//;
-      # return $s;
+      # $_->selector;
+      # get the selector and relativise to form
+      (my $s = $_->selector) =~ s/^.*form[^>]*>\s//;
+      return $s;
     })->first || '';
 }
 
@@ -101,9 +109,9 @@ sub _form_image_click {
   my ($self, $name) = (shift, shift);
   my ($x, $y) = map { int(rand($self->attr($_) || 1)) + 1 } qw{width height};
   # x and y if no name
-  return (x => $x, y => $y) unless $name;
+  return ([x => $x], [y => $y]) unless $name;
   # named x and y, with name
-  return ("$name.x" => $x, "$name.y" => $y);
+  return (["$name.x" => $x], ["$name.y" => $y]);
 }
 
 1;
